#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 shellmet
version:              0.0.4.0
visibility:           public
id:                   shellmet-0.0.4.0-JNTUtCaGFEG9aj1JYTOPt9
key:                  shellmet-0.0.4.0-JNTUtCaGFEG9aj1JYTOPt9
license:              MPL-2.0
copyright:            2019-2021 Kowainik
maintainer:           Kowainik <xrom.xkov@gmail.com>
author:               Dmitrii Kovanikov
homepage:             https://github.com/kowainik/shellmet
synopsis:             Out of the shell solution for scripting in Haskell
description:
    Shellmet provides easy and convenient way to call shell commands from Haskell programs

category:             Shell, Command Line
abi:                  1190eb2cc7bfad027235157a31215952
exposed:              True
exposed-modules:      Shellmet
import-dirs:          /usr/lib/ghc-8.10.5/site-local/shellmet-0.0.4.0
library-dirs:         /usr/lib/ghc-8.10.5/site-local/shellmet-0.0.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/shellmet-0.0.4.0
hs-libraries:         HSshellmet-0.0.4.0-JNTUtCaGFEG9aj1JYTOPt9
depends:              base-4.14.2.0 process-1.6.9.0 text-1.2.4.1
haddock-interfaces:   /usr/share/doc/haskell-shellmet/html/shellmet.haddock
haddock-html:         /usr/share/doc/haskell-shellmet/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

